@@ -1,4 +1,3 @@
-
 gamRR=function(
   fit,
   ref,
@@ -32,7 +31,6 @@ gamRR=function(
   ndata[,-match(est,names(ref))]=ref[,-match(est,names(ref))]
 
   rr=predict(fit,type="response",newdata=ndata)
-
   rr=as.numeric(rr)/as.numeric(rrref)
 
   i=1
@@ -58,35 +56,28 @@ gamRR=function(
   xy=data.frame(x=data[,est],rr=rr,u=u,l=l)
   xy=xy[order(xy$x),]
 
+  rangE=range(data[,est])
+  est.seq=seq(from=rangE[1],to=rangE[2],length.out=n.points)
+  seq.ind=which(abs(est.seq-as.numeric(ref[est]))==min(abs(est.seq-as.numeric(ref[est]))))
+  est.seq[seq.ind]=as.numeric(ref[est])
+
+  nxy=matrix(rep(0,n.points*4),ncol=4)
+  nxy=data.frame(nxy)
+  names(nxy)=c("x","rr","u","l")
+  for(i in 1:n.points){
+    ind=which(abs(xy$x-est.seq[i])==min(abs(xy$x-est.seq[i])))
+    nxy[i,]=xy[ind,]
+  }
+  nxy[seq.ind,2:4]=1
+
   if(plot){
     if(is.null(ylim)){ylim=c(min(xy$l),max(xy$u))}
-
-#    plot(xy[,c("x","rr")],type="l",ylim=ylim,ylab="RR",xlab=est)
-#    lines(xy[,c("x","u")],lty=2)
-#    lines(xy[,c("x","l")],lty=2)
-
-    rangE=range(data[,est])
-    est.seq=seq(from=rangE[1],to=rangE[2],length.out=n.points)
-    seq.ind=which(abs(est.seq-as.numeric(ref[est]))==min(abs(est.seq-as.numeric(ref[est]))))
-    est.seq[seq.ind]=as.numeric(ref[est])
-
-    nxy=matrix(rep(0,n.points*4),ncol=4)
-    nxy=data.frame(nxy)
-    names(nxy)=c("x","rr","u","l")
-    for(i in 1:n.points){
-      ind=which(abs(xy$x-est.seq[i])==min(abs(xy$x-est.seq[i])))
-      nxy[i,]=xy[ind,]
-    }
-    nxy[seq.ind,2:4]=1
-
-    plot(spline(nxy$x,nxy$rr,xmax=as.numeric(ref[,est])),
-         type="l",xlim=c(min(nxy$x),max(nxy$x)),ylim=ylim,xlab=est,ylab="RR")
+    plot(spline(nxy$x,nxy$rr,xmax=as.numeric(ref[,est])),type="l",xlim=c(min(nxy$x),max(nxy$x)),ylim=ylim,xlab=est,ylab="RR")
     lines(spline(nxy$x,nxy$l,xmax=as.numeric(ref[,est])),lty=2)
     lines(spline(nxy$x,nxy$u,xmax=as.numeric(ref[,est])),lty=2)
     lines(spline(nxy$x,nxy$rr,xmin=as.numeric(ref[,est])),lty=1)
     lines(spline(nxy$x,nxy$l,xmin=as.numeric(ref[,est])),lty=2)
     lines(spline(nxy$x,nxy$u,xmin=as.numeric(ref[,est])),lty=2)
-
   }
 
   return(nxy)
